@@ -4,7 +4,7 @@ Attean::RDF - Utility package for exporting shorthand functions for constructing
 
 =head1 VERSION
 
-This document describes Attean::RDF version 0.026
+This document describes Attean::RDF version 0.033
 
 =head1 SYNOPSIS
 
@@ -31,18 +31,18 @@ by default).
 
 =cut
 
-package Attean::RDF 0.026 {
+package Attean::RDF 0.033 {
 	use v5.14;
 	use warnings;
 
-	use Attean;
-	use List::MoreUtils qw(zip);
 	require Exporter::Tiny;
-	use namespace::clean;
-
 	our @ISA	= qw(Exporter::Tiny);
 	our @EXPORT	= qw(iri blank literal dtliteral langliteral variable triple quad triplepattern quadpattern bgp);
 
+	require Attean;
+	use List::MoreUtils qw(zip);
+	use namespace::clean;
+
 =item C<< variable( $value ) >>
 
 C<< Attean::Variable->new($value) >>
@@ -181,7 +181,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams.
+Copyright (c) 2014--2022 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
