@@ -4,7 +4,7 @@ AtteanX::Parser::NTriples - N-Triples Parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::NTriples version 0.030
+This document describes AtteanX::Parser::NTriples version 0.033
 
 =head1 SYNOPSIS
 
@@ -33,12 +33,22 @@ and <Attean::API::TripleParser>.
 
 =over 4
 
+=item C<< parse_iter_from_io( $fh ) >>
+
+Returns an L<Attean::API::Iterator> that result from parsing the data read from
+the L<IO::Handle> object C<< $fh >>.
+
+=item C<< parse_iter_from_bytes( $data ) >>
+
+Returns an L<Attean::API::Iterator> that result from parsing the data read from
+the UTF-8 encoded byte string C<< $data >>.
+
 =cut
 
 use v5.14;
 use warnings;
 
-package AtteanX::Parser::NTriples 0.030 {
+package AtteanX::Parser::NTriples 0.033 {
 	use utf8;
 	
 	use Attean;
@@ -75,6 +85,7 @@ Returns a list of file extensions that may be parsed with the parser.
 	with 'Attean::API::TripleParser';
 	with 'Attean::API::PullParser';
 	with 'Attean::API::Parser';
+	with 'Attean::API::CDTBlankNodeMappingParser';
 
 	sub _binding {
 		my $self	= shift;
@@ -106,7 +117,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams. This
+Copyright (c) 2014--2022 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
